/*
 *
 *  This file ist part of the software MonaLisa.
 *  MonaLisa is free software, dependend on non-free software. For more information read LICENCE and README.
 *
 *  (c) Molekulare Bioinformatik, Goethe University Frankfurt, Frankfurt am Main, Germany
 *
 */

package monalisa.addons.netviewer;

import edu.uci.ics.jung.visualization.control.AnimatedPickingGraphMousePlugin;
import edu.uci.ics.jung.visualization.control.CrossoverScalingControl;
import edu.uci.ics.jung.visualization.control.RotatingGraphMousePlugin;
import edu.uci.ics.jung.visualization.control.ShearingGraphMousePlugin;
import edu.uci.ics.jung.visualization.control.TranslatingGraphMousePlugin;
import edu.uci.ics.jung.visualization.annotations.AnnotatingModalGraphMouse.ModeKeyAdapter;
import edu.uci.ics.jung.visualization.control.AbstractModalGraphMouse;
import java.awt.event.InputEvent;

/**
 * GraphMouse with inverted zoom directions
 * @author Jens Einloft
 */
public class MyModalGraphMouse<V, E> extends AbstractModalGraphMouse {

    private GraphPopupMousePlugin gpmp;
    private NetViewer owner;   

    public MyModalGraphMouse(GraphPopupMousePlugin gpmp, NetViewer owner) {
        this(1.1F, 0.9090909F, gpmp, owner);        
    }

    public MyModalGraphMouse(float in, float out, GraphPopupMousePlugin gpmp, NetViewer owner) {
        super(in, out);
        this.owner = owner;
        this.gpmp = gpmp;
        loadPlugins();
        setModeKeyListener(new ModeKeyAdapter(this));
    }

    @Override
    protected void loadPlugins() {
        pickingPlugin = new MyPickingGraphMousePlugin(this, this.gpmp);
        animatedPickingPlugin = new AnimatedPickingGraphMousePlugin();
        translatingPlugin = new TranslatingGraphMousePlugin(InputEvent.BUTTON1_MASK);
        scalingPlugin = new MyScalingGraphMousePlugin(new MyCrossoverScalingControl(), 0, 1 / 1.1f, 1.1f, this.owner);
        rotatingPlugin = new RotatingGraphMousePlugin();
        shearingPlugin = new ShearingGraphMousePlugin();

        add(scalingPlugin);
        setMode(Mode.PICKING);
    }
    
    public MyScalingGraphMousePlugin getScalingPlugin() {
        return (MyScalingGraphMousePlugin) scalingPlugin;        
    }    
}
