/*
 *
 *  This file ist part of the software MonaLisa.
 *  MonaLisa is free software, dependend on non-free software. For more information read LICENCE and README.
 *
 *  (c) Molekulare Bioinformatik, Goethe University Frankfurt, Frankfurt am Main, Germany
 *
 */

package monalisa.addons.topological;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import monalisa.resources.ResourceManager;
import monalisa.resources.StringResources;
import org.jfree.chart.ChartFactory;
import org.jfree.chart.ChartFrame;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.data.category.DefaultCategoryDataset;


/**
 * Shows a histogram of the degrees of nodes
 * @author Jens Einloft
 */
public class NodesDegrees {

    private static final ResourceManager resources = ResourceManager.instance();
    private static final StringResources strings = resources.getDefaultStrings();

    private TopologicalFrame tpf;

    public NodesDegrees(Map<Integer, Integer> ndPlaces, Map<Integer, Integer> ndTransitions, Integer numberOfPlaces, Integer numberOfTransitions) {
        tpf = new TopologicalFrame();
        // Places
        createChartFrame(ndPlaces, new Double(numberOfPlaces), "Distribution of vertex degrees (Species)", "Species (in&out)");
        // Transitions
        createChartFrame(ndTransitions, new Double(numberOfTransitions), "Distribution of vertex degrees (Reactions)", "Reactions (in&out)");
        tpf.setVisible(true);
    }

    private void createChartFrame(Map<Integer, Integer> degrees, Double elementCounter, String chartTitle, String tabTitle) {
        ChartFrame chartFrame;
        List<Integer> listOfDegrees = new ArrayList<Integer>(degrees.keySet());
        Collections.sort(listOfDegrees);

        DefaultCategoryDataset datasetPlaces = new DefaultCategoryDataset();
        Integer lastValue = listOfDegrees.get(0);
        for (Integer i : listOfDegrees) {
            // fill gaps
            if(i != lastValue+1) 
                for(Integer j = 0; j < i-lastValue; j++)
                    datasetPlaces.setValue( 0 , "percent of vertices with this degree", new Integer(lastValue+j+1).toString());

            datasetPlaces.setValue( ((double) degrees.get(i) / elementCounter) *100.0 , "percent of vertices with this degree", i.toString());
            lastValue = i;
        }
        JFreeChart chart = ChartFactory.createBarChart(chartTitle, "vertex degree", "percent of vertices with this degree", datasetPlaces, PlotOrientation.VERTICAL, false,true, false);
        chartFrame = new ChartFrame("dummy",chart);
        chartFrame.setSize(500,500);
        tpf.mainTP.addTab(tabTitle, chartFrame.getRootPane());
    }

}
