/*
 *
 *  This file ist part of the software MonaLisa.
 *  MonaLisa is free software, dependend on non-free software. For more information read LICENCE and README.
 *
 *  (c) Molekulare Bioinformatik, Goethe University Frankfurt, Frankfurt am Main, Germany
 *
 */

package monalisa.results;

import monalisa.resources.StringResources;
import monalisa.tools.cluster.ClusterFunctions;
import monalisa.tools.distance.DistanceFunctions;

/**
 *
 * @author Jens Einloft
 */
public class ClusterTreeConfiguration implements Configuration {
    private static final long serialVersionUID = 6553322655138235537L;

    private final String distanceFunction;
    private final String clusterAlgorithm;
    private final float threshold;
    private final boolean includeTrivialTInvariants;
    private final String fileType;

    public ClusterTreeConfiguration(String distanceFunction, String clusterAlgorithm, float threshold, boolean includeTrivialTInvariants, String fileType) {
        this.distanceFunction = distanceFunction;
        this.clusterAlgorithm = clusterAlgorithm;
        this.threshold = threshold;
        this.includeTrivialTInvariants = includeTrivialTInvariants;
        this.fileType = fileType;
    }
    
    @Override
    public String toString(StringResources strings) {
        String distance = DistanceFunctions.getName(distanceFunction);
        String cluster = ClusterFunctions.getName(clusterAlgorithm);
        String with = strings.get(includeTrivialTInvariants ? "With" : "Without");
        String percent = String.format("%.0f", threshold);
        return strings.get("ClusterTable", fileType, cluster, distance, percent, with);
    }
    
    @Override
    public String toString() {
        return String.format("%s-%s-%s-%d-%s",
            fileType, clusterAlgorithm, distanceFunction, (int)threshold,
            (includeTrivialTInvariants ? "with" : "without") +  "-trivial-em");
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (!(obj instanceof ClusterTreeConfiguration))
            return false;
        ClusterTreeConfiguration other = (ClusterTreeConfiguration) obj;
        return distanceFunction == other.distanceFunction &&
            clusterAlgorithm == other.clusterAlgorithm &&
            threshold == other.threshold &&
            includeTrivialTInvariants == other.includeTrivialTInvariants && fileType == other.fileType;
    }
    
    @Override
    public int hashCode() {
        return distanceFunction.hashCode() ^ clusterAlgorithm.hashCode();
    }

    public Boolean isExportable() {
        return false;
    }

    public String getClusterAlgorithm() {
        return clusterAlgorithm;
    }

    public String getDistanceFunction() {
        return distanceFunction;
    }

    public boolean isIncludeTrivialTInvariants() {
        return includeTrivialTInvariants;
    }

    public float getThreshold() {
        return threshold;
    }

}
