/*
 *
 *  This file ist part of the software MonaLisa.
 *  MonaLisa is free software, dependend on non-free software. For more information read LICENCE and README.
 *
 *  (c) Molekulare Bioinformatik, Goethe University Frankfurt, Frankfurt am Main, Germany
 *
 */

package monalisa.results;

import monalisa.resources.StringResources;
import monalisa.tools.distance.DistanceFunctions;

public final class DistanceMatrixConfiguration implements Configuration {
    private static final long serialVersionUID = 8988219279191863395L;
    
    private final String distanceFunctionName;
    private final boolean includeTrivialTInvariants;
    
    public DistanceMatrixConfiguration(String distanceFunctionName,
            boolean includeTrivialTInvariants) {
        this.distanceFunctionName = distanceFunctionName;
        this.includeTrivialTInvariants = includeTrivialTInvariants;
    }

    public String getDistanceFunctionName() {
        return distanceFunctionName;
    }
    
    public boolean hasTrivialTInvariants() {
        return includeTrivialTInvariants;
    }
    
    @Override
    public String toString() {
        return String.format("%s-%s", distanceFunctionName,
            (includeTrivialTInvariants ? "with" : "without") +  "-trivial-em");
    }

    @Override
    public String toString(StringResources strings) {
        String function = DistanceFunctions.getName(distanceFunctionName);
        String with = strings.get(includeTrivialTInvariants ? "With" : "Without");
        return strings.get("DistanceMatrix", function, with);
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        return
            prime + (distanceFunctionName == null ? 0 :
                distanceFunctionName.hashCode()) * prime
            + (includeTrivialTInvariants ? 1231 : 1237);  
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        DistanceMatrixConfiguration other = (DistanceMatrixConfiguration) obj;
        if (distanceFunctionName == null) {
            if (other.distanceFunctionName != null)
                return false;
        } else if (!distanceFunctionName.equals(other.distanceFunctionName))
            return false;
        if (includeTrivialTInvariants != other.includeTrivialTInvariants)
            return false;
        return true;
    }

    public Boolean isExportable() {
        return true;
    }
}
