/*
 *
 *  This file ist part of the software MonaLisa.
 *  MonaLisa is free software, dependend on non-free software. For more information read LICENCE and README.
 *
 *  (c) Molekulare Bioinformatik, Goethe University Frankfurt, Frankfurt am Main, Germany
 *
 */

package monalisa.tools.knockout;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import monalisa.data.pn.PetriNet;
import monalisa.data.pn.Transition;
import monalisa.data.pn.UniquePetriNetEntity;

public class SingleTransitionKnockout extends KnockoutAlgorithm {

    private Iterator<Transition> iterator;
    private List<UniquePetriNetEntity> currentKnockouts;
    
    SingleTransitionKnockout(PetriNet pn) {
        super(pn);
        iterator = pn.transitions().iterator();
    }
    
    SingleTransitionKnockout(PetriNet pn, List<Transition> transitions) {
        super(pn);
        iterator = transitions.iterator();
    }

    @Override
    protected PetriNet getNextKnockOutNetwork() {
        PetriNet copy = new PetriNet(getPetriNet());
        Transition transition = iterator.next();
        
        currentKnockouts = new ArrayList<UniquePetriNetEntity>();
        currentKnockouts.add(transition);
        
        copy.removeTransition(transition);
        return copy;
    }

    @Override
    protected boolean hasNextKnockOutNetwork() {
        return iterator.hasNext();
    }
    
    protected List<UniquePetriNetEntity> getKnockoutEntities() {
        return currentKnockouts;
    }

    @Override
    protected int getTotalKnockouts() {
        return getPetriNet().transitions().size();
    }
}
